from setuptools import setup

setup(name='akash_iq_library',
      version='0.1',
      description='contains many data science modules',
      author='Akash Kumar',
      packages=['akash_iq_library'],
      zip_safe=False)